Recurrence class

Constructors

Recurrence({required int? frequency, required int? interval, required dynamic startTime, required dynamic type})
Recurrence.fromJson(Map<String, dynamic> json)
factory

Properties

frequency int?
final
hashCode int
The hash code for this object.
no setterinherited
interval int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startTime → dynamic
final
type → dynamic
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited