RootProps class

Constructors

RootProps({required String? pageId, String? hasSysClr = "0", String sysClr = "#FFFFFF", int? x, int? y, int? constHeight, int? constWidth, String? asset, String? objectFit})
RootProps.fromJson(Map<String, dynamic> json)
factory

Properties

asset String?
final
constHeight int?
final
constWidth int?
final
hashCode int
The hash code for this object.
no setterinherited
hasSysClr String?
final
objectFit String?
final
pageId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sysClr String
final
x int?
final
y int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited