RootWidget class
Constructors
-
RootWidget({required int? type, required String? id, required int? previewState, required WidgetProps? props, required List<
WidgetWidget> widgets}) -
RootWidget.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
final
- previewState → int?
-
final
- props → WidgetProps?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → int?
-
final
-
widgets
→ List<
WidgetWidget> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited