Settings class

Constructors

Settings({required int? spinCount, required dynamic completeParent, required int? subTasksCount, required dynamic hideOnComplete})
Settings.fromJson(Map<String, dynamic> json)
factory

Properties

completeParent → dynamic
final
hashCode int
The hash code for this object.
no setterinherited
hideOnComplete → dynamic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spinCount int?
final
subTasksCount int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited