Variant class

Constructors

Variant({required List<Root> root, required VariantVars? vars, required Actions? actions, required List referrerRewards, required List rewards, required Actions? rewardsDelivery, required dynamic uiTrigger, required dynamic defaultRoot, required dynamic rewardsDep, required dynamic jactions, required dynamic jui})
Variant.fromJson(Map<String, dynamic> json)
factory

Properties

actions Actions?
final
defaultRoot → dynamic
final
hashCode int
The hash code for this object.
no setterinherited
jactions → dynamic
final
jui → dynamic
final
referrerRewards List
final
rewards List
final
rewardsDelivery Actions?
final
rewardsDep → dynamic
final
root List<Root>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uiTrigger → dynamic
final
vars VariantVars?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited