Floater class

Inheritance

Constructors

Floater({Key? key, required double initialX, required double initialY, required double initialWidth, required double initialHeight, required String assetUrl, required Map<String, dynamic> assets, required String asset, required String objectFit, required String taskId, required Function closeCallback, double screenWidth = 360, double screenHeight = 720, required ValueNotifier<Offset> updateFloaterPosition, required double paddingTop, required List<UIComponent> widgets, required String rootId, required ValueNotifier<bool> isFullPageNotifier})
const

Properties

asset String
final
assets Map<String, dynamic>
final
assetUrl String
final
closeCallback Function
final
hashCode int
The hash code for this object.
no setterinherited
initialHeight double
final
initialWidth double
final
initialX double
final
initialY double
final
isFullPageNotifier ValueNotifier<bool>
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
objectFit String
final
paddingTop double
final
rootId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenHeight double
final
screenWidth double
final
taskId String
final
updateFloaterPosition ValueNotifier<Offset>
final
widgets List<UIComponent>
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<Floater>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited